@@ -17,6 +17,7 @@
 # under the License.
 import json
 import logging
+import os
 import sys
 from datetime import datetime, timedelta
 from pathlib import Path
@@ -86,8 +87,20 @@ def spotrix() -> None:
 @with_appcontext
 def init() -> None:
     """Inits the Spotrix application"""
+    default_fab_cmd = """spotrix fab create-admin \
+              --username admin \
+              --firstname Spotrix \
+              --lastname Admin \
+              --email spotrix.guinsoolab@gmail.com \
+              --password admin"""
+    os.system(default_fab_cmd)
+    default_db_upgrade = "spotrix db upgrade"
+    os.system(default_db_upgrade)
+    # Sync permissions
     appbuilder.add_permissions(update_perms=True)
     security_manager.sync_role_definitions()
+    # Load examples
+    load_examples()
 
 
 @spotrix.command()
@@ -98,9 +111,18 @@ def version(verbose: bool) -> None:
     print(Fore.BLUE + "-=" * 15)
     print(
         Fore.YELLOW
-        + "Spotrix "
+        + """
+ ___                  _                  
+(  _`\               ( )_        _       
+| (_(_) _ _      _   | ,_) _ __ (_)      
+`\__ \ ( '_`\  /'_`\ | |  ( '__)| |(`\/')
+( )_) || (_) )( (_) )| |_ | |   | | >  < 
+`\____)| ,__/'`\___/'`\__)(_)   (_)(_/\_)
+       | |                               
+       (_)                               
+        """
         + Fore.CYAN
-        + "{version}".format(version=app.config["VERSION_STRING"])
+        + "\nVersion: {version}".format(version=app.config["VERSION_STRING"])
     )
     print(Fore.BLUE + "-=" * 15)
     if verbose:
